# plugins/commands.py

import logging
import simplematrixbotlib as botlib

async def handle_command(room, message, bot, PREFIX):
    """
    Function to handle the !commands command.

    Args:
        room (Room): The Matrix room where the command was invoked.
        message (RoomMessage): The message object containing the command.

    Returns:
        None
    """
    match = botlib.MessageMatch(room, message, bot, PREFIX)
    if match.is_not_from_this_bot() and match.prefix() and match.command("commands"):
        logging.info("Fetching commands documentation")
        commands_message = """
# 🍄 Funguy Bot Commands 🍄

🃏 **!fortune**
Returns a random fortune message.
Executes the `/usr/games/fortune` utility and sends the output as a message to the chat room.

⏰ **!date**
Displays the current date and time.
Fetches the current date and time using Python's `datetime` module and sends it in a formatted message to the chat room.

💻 **!proxy**
Retrieves a tested/working random SOCKS5 proxy.
Fetches a list of SOCKS5 proxies, tests their availability, and sends the first working proxy to the chat room.

📶 **!isup <domain/ip>**
Checks if the specified domain or IP address is reachable.
Checks if the specified domain or IP address is reachable by attempting to ping it. If DNS resolution is successful, it checks HTTP and HTTPS service availability by sending requests to the domain.

☯ **!karma <user>**
Retrieves the karma points for the specified user.
Retrieves the karma points for the specified user from a database and sends them as a message to the chat room.

⇧ **!karma <user> up**
Increases the karma points for the specified user by 1.
Increases the karma points for the specified user by 1 in the database and sends the updated points as a message to the chat room.

⇩ **!karma <user> down**
Decreases the karma points for the specified user by 1.
Decreases the karma points for the specified user by 1 in the database and sends the updated points as a message to the chat room.

# 🌟 Funguy Bot Credits 🌟

🧙‍♂️ Creator & Developer:
   - Hash Borgir is the author of 🍄Funguy Bot🍄. (@hashborgir:mozilla.org)

# Join our Matrix Room:

[Self-hosting | Security | Sysadmin | Homelab | Programming](https://chat.mozilla.org/#/room/#selfhosting:mozilla.org)
        """
        await bot.api.send_markdown_message(room.room_id, commands_message)
        logging.info("Sent commands documentation to the room")
